import REST from '../../api/rest-axios';

export async function fetchFromRelationships(field, relationships) {
    field = relationships[field] ? field : `${field}_static`;
    
    if (relationships[field].links) {
        const contentLink = relationships[field].links.related.href;
        return REST.get(contentLink)
            .then(contentFetch => contentFetch.data.data)
            .catch(error => {
                this.error = 'Failed to fetch data';
                console.error('Issue with getNodeData', error);
            });
    }
    return null;
}

export function getCleanDate(date) {
    return {
      d: date.split('-')[2],
      m: new Intl.DateTimeFormat('fr-FR', { month: 'long' }).format(new Date(date)),
      y: date.split('-')[0],
    }
}

export async function getRelatedEtape(direction, path) {
    const getRelatedEtapeContent = (relatedEtapeData) => {
        if (relatedEtapeData) {
            return fetchFromRelationships('field_vignette', relatedEtapeData.relationships)
                .then(vignetteFetch => {
                    if (vignetteFetch) {
                        return {
                            url: relatedEtapeData.attributes.metatag.find(tag => tag.tag === "link")?.attributes.href,
                            couleur: relatedEtapeData.attributes.field_couleur,
                            title: relatedEtapeData.attributes.title,
                            postalCode: relatedEtapeData.attributes.field_adresse.postal_code,
                            dates: {
                                start: getCleanDate(relatedEtapeData.attributes.field_dates.value),
                                end: getCleanDate(relatedEtapeData.attributes.field_dates.end_value),
                            },
                            vignette: {
                                url: {
                                    original: vignetteFetch.attributes.uri.url,
                                    small: vignetteFetch.attributes.image_style_uri.content_small,
                                    medium: vignetteFetch.attributes.image_style_uri.content_medium,
                                    large: vignetteFetch.attributes.image_style_uri.content_large,
                                },
                                alt: relatedEtapeData.relationships.field_vignette.data.meta.alt,
                            },
                        }
                    }
                });
        }
    }

    const allEtapesPromise = REST.get('/jsonapi/views/etapes/block_1/');
    
    return allEtapesPromise.then(allEtapesData => {
        for (let [index, etape] of allEtapesData.data.data.entries()) {
            if (etape.attributes.metatag.some(tag => 
                tag.tag === "link" && tag.attributes.href === path
            )) {
                const relatedEtapeIndex = direction === 'next' ? index + 1 : index - 1;
                return getRelatedEtapeContent(allEtapesData.data.data[relatedEtapeIndex]);
            }
        }
    });    
}